@@ -133,7 +133,7 @@ class CoolE(object):
             self.debug("最多存储30个字段！")
             return
         self.report_content[field] = data
-        self.field_num += 1
+        self.field_num = len(self.report_content.keys())
     
     def updateContent(self, field:str, data):
         self.content_content[field] = data
